instrumenttools.Vibraphone
==========================

.. abjad-lineage:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone

.. autoclass:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Vibraphone.Vibraphone.Vibraphone.__repr__
   :noindex:
